package com.zayac.admin.system.model.req;

import java.io.Serial;
import java.time.LocalDateTime;

import com.zayac.admin.common.enums.DisEnableStatusEnum;
import jakarta.validation.constraints.*;

import lombok.Data;

import io.swagger.v3.oas.annotations.media.Schema;

import org.hibernate.validator.constraints.Length;

import top.continew.starter.extension.crud.model.req.BaseReq;

/**
 * 创建或修改平台信息
 *
 * @author zayac
 * @since 2024/05/14 12:28
 */
@Data
@Schema(description = "创建或修改平台信息")
public class PlatformReq extends BaseReq {

    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * 平台名称
     */
    @Schema(description = "平台名称")
    @NotBlank(message = "平台名称不能为空")
    @Length(max = 100, message = "平台名称长度不能超过 {max} 个字符")
    private String name;

    /**
     * 平台别称
     */
    @Schema(description = "平台别称")
    @NotBlank(message = "平台别称不能为空")
    @Length(max = 100, message = "平台别称长度不能超过 {max} 个字符")
    private String nickname;

    /**
     * 平台地址
     */
    @Schema(description = "平台地址")
    @NotBlank(message = "平台地址不能为空")
    @Length(max = 100, message = "平台地址长度不能超过 {max} 个字符")
    private String url;

    /**
     * 平台ID
     */
    @Schema(description = "平台ID")
    @NotNull(message = "平台ID不能为空")
    private Integer platformId;

    /**
     * 状态(1启用,2禁用)
     */
    @Schema(description = "平台状态（1：启用；2：禁用）", type = "Integer", allowableValues = {"1", "2"}, example = "1")
    @NotNull(message = "平台状态非法")
    private DisEnableStatusEnum status;

    /**
     * 描述
     */
    @Length(max = 200, message = "平台描述长度不能超过 {max} 个字符")
    private String description;
}